@@ -49,13 +49,17 @@ class SessionManager:
     def startAWSSession(self, sessionInfo: SessionInfo):
         aws = AwsServices()
 
-        stsToken = {}
-        stsToken["AccessKeyId"]     = sessionInfo.credentials['accessKey']
-        stsToken["SecretAccessKey"] = sessionInfo.credentials['secretKey']
-        stsToken["SessionToken"]    = ""
-        stsToken["Expiration"]      = ""
+        _stsToken                                   = {}
+        _stsToken["Credentials"]                    = {}
+        _stsToken["Credentials"]["AccessKeyId"]     = sessionInfo.credentials['accessKey']
+        _stsToken["Credentials"]["SecretAccessKey"] = sessionInfo.credentials['secretKey']
+        _stsToken["Credentials"]["SessionToken"]    = ""
+        _stsToken["Credentials"]["Expiration"]      = ""
 
-        sessionInfo.stsToken = stsToken
+        callerIdentity = aws.getCallerIdentity(_stsToken)
+
+        sessionInfo.stsToken       = _stsToken["Credentials"]
+        sessionInfo.callerIdentity = callerIdentity
 
         return self.createAWSSessionOnTerminalUser(sessionInfo)
 
@@ -263,7 +267,7 @@ rm {self.SCRIPTS_PREFIX_NAME_FILE}*
         if AwsSeeState().NEW_TERMINAL:
             output += f"\n\n {Style.IBLUE}--> {Style.IMAGENTA}Session opened in another terminal..."
 
-        output += "\n"
+        output += f"{Style.RESET}"
         return output
 
     # This is the same AWS Session credentials information for the user in case he/she wants to open using the Clipboard
